@@ -35,9 +35,24 @@ describe("basic type checking", function() {
         assert.ok(n.Expression.check(ifFoo.test));
         assert.ok(n.Identifier.check(ifFoo.test));
         assert.ok(!n.Statement.check(ifFoo.test));
+        assert.equal(
+          b.importDeclaration(
+            [b.importDefaultSpecifier(b.identifier("foo"))], b.literal("bar")
+          ).importKind,
+          "value"
+        );
+        assert.throws(function () {
+            b.importDeclaration(
+              [b.importDefaultSpecifier(b.identifier("foo"))],
+              b.literal("bar"),
+              "baz"
+            )
+          }
+        );
         assert.ok(n.ImportDeclaration.check(
           b.importDeclaration(
-            [b.importDefaultSpecifier(b.identifier("foo"))], b.literal("bar"))
+            [b.importDefaultSpecifier(b.identifier("foo"))], b.literal("bar"),
+              "type")
           )
         );
         assert.ok(n.ImportDeclaration.check(
@@ -311,6 +326,13 @@ describe("types.getFieldValue", function() {
             []
         );
     });
+
+    it("should handle undefined objects", function() {
+        assert.equal(
+            types.getFieldValue(undefined, "name"),
+            undefined
+        );
+    });
 });
 
 describe("types.eachField", function() {
@@ -1118,6 +1140,29 @@ describe("scope methods", function () {
         assert.deepEqual(names, ["x", "xyDefault", "xyNamespace", "z"]);
     });
 
+    it("should work for ES6 syntax (espree)", function() {
+        var names;
+
+        var ast = require("espree").parse([
+            "var zap;",
+            "export default function(zom) {",
+            "    var innerFn = function(zip) {};",
+            "    return innerFn(zom);",
+            "};"
+        ].join("\n"), {
+            sourceType: "module",
+            ecmaVersion: 6
+        });
+
+        types.visit(ast, {
+            visitFunctionDeclaration: function(path) {
+                names = Object.keys(path.scope.lookup("zap").getBindings()).sort();
+                assert.deepEqual(names, ["zap"]);
+                this.traverse(path);
+            }
+        });
+    });
+
     it("should inject temporary into current scope", function() {
         var ast = parse(scope.join("\n"));
         var bindings;
@@ -1264,6 +1309,11 @@ describe("array and object pattern scope", function() {
     // ObjectPattern with Property and SpreadProperty
     // ArrayPattern with SpreadElement
     describe("esprima", function() {
+        var types = require('../fork')([
+            require("../def/esprima")
+        ]);
+        var b = types.builders;
+
         var objectPattern;
         var arrayPattern;
 
@@ -1321,6 +1371,14 @@ describe("array and object pattern scope", function() {
     // ObjectPattern with PropertyPattern and SpreadPropertyPattern
     // ArrayPatterhn with SpreadElementPattern
     describe("Mozilla Parser API", function() {
+        var types = require('../fork')([
+            require("../def/core"),
+            require("../def/es6"),
+            require("../def/es7"),
+            require("../def/mozilla"),
+        ]);
+        var b = types.builders;
+
         var objectPattern;
         var arrayPattern;
 
